\name{HaploDistScan-package}
\alias{HaploDistScan-package}
\alias{HaploDistScan}
\docType{package}
\title{
	Scan for unusual distributions of pairwise distances between chromosomes
}
\description{
	Uses phased SNP genotypes from a set of individuals to perform a scan for genomic 
	regions displaying unusual distributions of pairwise distances between chromosomes. 
	This procedure provides a means to detect regions with suppressed effective 
	recombination rates, due, for example, to balancing selection on long 
	haplotyes or large inversions.
}
\details{
	\tabular{ll}{
		Package: \tab HaploDistScan\cr
		Type: \tab Package\cr
		Version: \tab 0.2\cr
		Date: \tab 2015-09-04\cr
		License: \tab GPL (>=2)\cr
	}
}
\section{Functions}{
	\tabular{ll}{
		\code{\link{generate_geno_df}}\cr
		\code{\link{excise_individuals}}\cr
		\code{\link{construct_window_annotation}}\cr
		\code{\link{calculate_haplotype_distances}}\cr
		\code{\link{plot_hap_dist_scan}}\cr
		\code{\link{plot_top_regions}}\cr
		\code{\link{output_peak_table}}\cr
	}
}
\author{
	Author: Mats E. Pettersson\cr
	Maintainer: Mats E. Pettersson <mats.pettersson@imbim.uu.se>
}
\references{
	Software_paper (TBD)
}
\keyword{ package }

\examples{
	#Load a genotype data frame generated by 'generate_geno_df.'
	data("ruff_chr6_genotypes")
	
	#Construct a data frame of non-overlapping, 100 kb windows along the genome.
	ruff_chr6_w <- construct_window_annotation(ruff_chr6$geno)
	
	#Perform the haplotype distance scan.
	ruff_chr6_s <- calculate_haplotype_distances(ruff_chr6$geno, ruff_chr6_w)
	
	#Visualise the results and extract significant regions.
	ruff_chr6_top_pos <- plot_hap_dist_scan(ruff_chr6_s, ruff_chr6_w, 50)
	output_peak_table(ruff_chr6_top_pos, ruff_chr6_w, hap_dist_scan = ruff_chr6_s)
}